@@ -100,7 +100,7 @@ HD_DEFINE_PLUGIN_MODULE (CCCHHDoorIsDesktopWidget, ccchh_dooris_desktop_widget,
 
 
 
-#define DEBUG
+// #define DEBUG
 
 #ifdef DEBUG
 
@@ -445,9 +445,9 @@ draw (CCCHHDoorIsDesktopWidget *self, cairo_t *cr)
 	// if not connected, overlay icon with "disconnected" image
 	if (!self->connected) {
 		g_debug(WIDGET_NAME": not connected, overlay image");
-		cairo_surface_t *image_overlay = cairo_image_surface_create_from_png(IMAGE_OVERLAY_DISCONNECTED);
+		cairo_surface_t *image_overlay = cairo_image_surface_create_from_png(IMAGE_DISCONNECTED);
 		cairo_set_source_surface(cr, image_overlay, 5, 5);
-		cairo_paint_with_alpha(cr, self->current_alpha);
+		cairo_paint_with_alpha(cr, self->current_alpha * IMAGE_DISCONNECTED_ALPHA);
 		cairo_surface_destroy(image_overlay);
 	}
 
@@ -518,7 +518,7 @@ show_status_banner (CCCHHDoorIsDesktopWidget *self)
 			state_text = _("CCCHH: Unknown");
 			// repurpose ts_text to display self->too_old
 			g_free (ts_text);
-			ts_text = gstrdup((self->too_old) ? _("(data too old)") : (""));
+			ts_text = g_strdup((self->too_old) ? _("(data too old)") : (""));
 			break;
 	}
 
