@@ -36,7 +36,8 @@
 #define IMAGE_DOORIS_OPEN			DATADIR"/dooris_open.png"
 #define IMAGE_DOORIS_CLOSED			DATADIR"/dooris_closed.png"
 #define IMAGE_DOORIS_FNORD			DATADIR"/dooris_fnord.png"
-#define IMAGE_OVERLAY_DISCONNECTED	DATADIR"/dooris_notavail.png"
+#define IMAGE_DISCONNECTED			DATADIR"/dooris_notavail.png"
+#define IMAGE_DISCONNECTED_ALPHA	0.63
 
 // widget size in pixels
 #define IMAGE_WIDGET_WIDTH	102
